
# Type: id


The official schema URI

URI: [meta:id](https://w3id.org/biolink/biolinkml/meta/id)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>REQ</sub> [Uri](types/Uri.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
